@@ -127,6 +127,9 @@ Retrieves the Bio::Phylo::Taxa::Taxon object linked to the invocant.
 
 =head1 SEE ALSO
 
+There is a mailing list at L<https://groups.google.com/forum/#!forum/bio-phylo> 
+for any user or developer questions and discussions.
+
 =over
 
 =item L<Bio::Phylo::Matrices::Datum>
