@@ -54,8 +54,12 @@ BEGIN {
       _NS_XML_
       _NS_TOL_
       _NS_CDAO_
+      _NS_BIOPHYLO_
+      _NS_SKOS_
       _NEXML_VERSION_
       _PI_
+      _NS_PHYLOXML_
+      _NS_TB2PURL_
     );
     %EXPORT_TAGS = (
         'all'         => [@EXPORT_OK],
@@ -91,7 +95,7 @@ BEGIN {
               _SET_
               _MODEL_
               _OPERATION_
-              )
+            )
         ],
         'functions' => [
             qw(
@@ -101,7 +105,7 @@ BEGIN {
               looks_like_class
               looks_like_instance
               looks_like_implementor
-              )
+            )
         ],
         'namespaces' => [
             qw(
@@ -116,7 +120,11 @@ BEGIN {
               _NS_XML_
               _NS_TOL_
               _NS_CDAO_
-              )
+              _NS_BIOPHYLO_
+              _NS_SKOS_
+              _NS_PHYLOXML_
+              _NS_TB2PURL_
+            )
         ]
     );
 }
@@ -126,17 +134,21 @@ BEGIN {
 # If the result after optimization and constant folding is either a constant
 # or a lexically-scoped scalar which has no other references, then it will
 # be used in place of function calls made without & or do."
-sub _NS_OWL_ ()     { 'http://www.w3.org/2002/07/owl#' }
-sub _NS_DC_ ()      { 'http://purl.org/dc/elements/1.1/' }
-sub _NS_DCTERMS_ () { 'http://purl.org/dc/terms/' }
-sub _NS_NEXML_ ()   { 'http://www.nexml.org/2009' }
-sub _NS_RDF_ ()     { 'http://www.w3.org/1999/02/22-rdf-syntax-ns#' }
-sub _NS_RDFS_ ()    { 'http://www.w3.org/2000/01/rdf-schema#' }
-sub _NS_XSI_ ()     { 'http://www.w3.org/2001/XMLSchema-instance' }
-sub _NS_XSD_ ()     { 'http://www.w3.org/2001/XMLSchema#' }
-sub _NS_XML_ ()     { 'http://www.w3.org/XML/1998/namespace' }
-sub _NS_TOL_ ()     { 'http://tolweb.org/tree/home.pages/downloadtree.html#' }
-sub _NS_CDAO_ ()    { 'http://www.evolutionaryontology.org/cdao/1.0/cdao.owl#' }
+sub _NS_OWL_ ()      { 'http://www.w3.org/2002/07/owl#' }
+sub _NS_DC_ ()       { 'http://purl.org/dc/elements/1.1/' }
+sub _NS_DCTERMS_ ()  { 'http://purl.org/dc/terms/' }
+sub _NS_NEXML_ ()    { 'http://www.nexml.org/2009' }
+sub _NS_RDF_ ()      { 'http://www.w3.org/1999/02/22-rdf-syntax-ns#' }
+sub _NS_RDFS_ ()     { 'http://www.w3.org/2000/01/rdf-schema#' }
+sub _NS_XSI_ ()      { 'http://www.w3.org/2001/XMLSchema-instance' }
+sub _NS_XSD_ ()      { 'http://www.w3.org/2001/XMLSchema#' }
+sub _NS_XML_ ()      { 'http://www.w3.org/XML/1998/namespace' }
+sub _NS_TOL_ ()      { 'http://tolweb.org/tree/home.pages/downloadtree.html#' }
+sub _NS_CDAO_ ()     { 'http://www.evolutionaryontology.org/cdao/1.0/cdao.owl#' }
+sub _NS_BIOPHYLO_ () { 'http://search.cpan.org/dist/Bio-Phylo/terms#' }
+sub _NS_SKOS_ ()     { 'http://www.w3.org/2004/02/skos/core#' }
+sub _NS_PHYLOXML_ () { 'http://www.phyloxml.org/1.10/terms#' }
+sub _NS_TB2PURL_ ()  { 'http://purl.org/phylo/treebase/phylows/' }
 
 sub _NEXML_VERSION_ () { '0.9' }
 sub _NONE_ ()          { 1 }
@@ -356,6 +368,9 @@ Tests if argument looks like a loadable class name.
 
 =head1 SEE ALSO
 
+There is a mailing list at L<https://groups.google.com/forum/#!forum/bio-phylo> 
+for any user or developer questions and discussions.
+
 =over
 
 =item L<Bio::Phylo::Manual>
